CREATE TABLE language (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 language VARCHAR NOT NULL,
 country VARCHAR NOT NULL,
 UNIQUE (language, country)
);
CREATE TABLE creation_tool (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 name VARCHAR NOT NULL,
 version VARCHAR NOT NULL,
 UNIQUE (name, version)
);
CREATE TABLE property_type (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 name VARCHAR NOT NULL UNIQUE
);
CREATE TABLE data_type (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 name VARCHAR NOT NULL UNIQUE
);
CREATE TABLE hetman_user (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 login VARCHAR UNIQUE NOT NULL,
 password_code VARCHAR NOT NULL,
 role_id BIGINT NOT NULL,
 name VARCHAR NOT NULL,
 surname VARCHAR NOT NULL,
 email VARCHAR NOT NULL,
 blocked BOOLEAN DEFAULT FALSE,
 language_id BIGINT NOT NULL,
 interface_language_code VARCHAR NOT NULL,
 initial_quality_level_id BIGINT NOT NULL,
 proof_of_life TIMESTAMP
);
CREATE TABLE document (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 document_type_id BIGINT NOT NULL,
 document_source_url VARCHAR
);
CREATE TABLE unit (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 document_id BIGINT,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 segment_type_id BIGINT NOT NULL,
 source_language_id BIGINT NOT NULL,
 document_position FLOAT NOT NULL,
 package_name VARCHAR NOT NULL
);
CREATE TABLE variant (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 unit_id int NOT NULL,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL,
 language_id BIGINT NOT NULL,
 creation_tool_id BIGINT NOT NULL,
 data_type_id BIGINT NOT NULL,
 quality_level_id BIGINT NOT NULL,
 context BIGINT,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 segment VARCHAR NOT NULL
);
CREATE TABLE document_property (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 document_id BIGINT NOT NULL,
 text VARCHAR NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 property_type_id BIGINT NOT NULL,
 language_id BIGINT NOT NULL,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL
);
CREATE TABLE document_note (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 document_id BIGINT NOT NULL,
 text VARCHAR NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 language_id BIGINT NOT NULL,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL
);
CREATE TABLE unit_property (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 unit_id BIGINT NOT NULL,
 text VARCHAR NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 property_type_id BIGINT NOT NULL,
 language_id BIGINT NOT NULL,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL
);
CREATE TABLE unit_note (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 unit_id BIGINT NOT NULL,
 text VARCHAR NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 language_id BIGINT NOT NULL,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL
);
CREATE TABLE variant_property (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 variant_id BIGINT NOT NULL,
 text VARCHAR NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 property_type_id BIGINT NOT NULL,
 language_id BIGINT NOT NULL,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL
);
CREATE TABLE variant_note (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 variant_id BIGINT NOT NULL,
 text VARCHAR NOT NULL,
 creation_date TIMESTAMP NOT NULL,
 change_date TIMESTAMP NOT NULL,
 language_id BIGINT NOT NULL,
 creating_user_id BIGINT NOT NULL,
 changing_user_id BIGINT NOT NULL
);
CREATE TABLE changed_unit (
 unit_id BIGINT NOT NULL,
 document_type_id BIGINT NOT NULL,
 translatica_id VARCHAR,
 package_name VARCHAR
);
CREATE TABLE user_invoice_data (
 id INTEGER PRIMARY KEY AUTOINCREMENT,
 user_id BIGINT NOT NULL,
 company_name VARCHAR,
 personal_id_number VARCHAR,
 tax_id_number VARCHAR ,
 street VARCHAR,
 postal_code VARCHAR,
 city VARCHAR,
 country VARCHAR
);
 CREATE TABLE contract_template (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   language BIGINT ,
   content BIGINT
 );
 CREATE TABLE price_estimation_model (
   id SERIAL PRIMARY KEY,
   description BIGINT
 );
 CREATE TABLE translation_contract (
   id SERIAL PRIMARY KEY,
   contract_template INT ,
   ordering_party BIGINT ,
   providing_party BIGINT ,
   price_estimation_model INT ,
   created TIMESTAMP NOT NULL,
   accepted TIMESTAMP,
   effective TIMESTAMP,
   expires TIMESTAMP,
   cancelled TIMESTAMP
 );
 CREATE TABLE translation_competence (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   created TIMESTAMP,
   source_language BIGINT ,
   source_quality_level BIGINT ,
   target_language BIGINT ,
   target_quality_level BIGINT ,
   context BIGINT,
   translation_contract BIGINT ,
   price_per_unit_value DOUBLE PRECISION,
   price_per_unit_currency VARCHAR,
   evaluation DOUBLE PRECISION,
   removed TIMESTAMP,
   task_type BIGINT,
   grade DOUBLE PRECISION
 );
 CREATE TABLE translation_competence_selector (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   activated TIMESTAMP NOT NULL,
   deactivated TIMESTAMP,
   source_url_pattern VARCHAR,
   document_format VARCHAR,
   document_category VARCHAR,
   translation_competence BIGINT NOT NULL,
   autoconfirm BOOLEAN,
   intermediate_updates BOOLEAN,
   index_id BIGINT,
   minimum_grade DOUBLE PRECISION
 );
 CREATE TABLE translation_receipt (
   id SERIAL PRIMARY KEY,
   date DATE,
   translation_contract BIGINT ,
   from_date TIMESTAMP,
   to_date TIMESTAMP,
   total_amount_value DOUBLE PRECISION,
   total_amount_currency VARCHAR
 );
 CREATE TABLE translation_task (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   creator BIGINT ,
   document BIGINT ,
   updated BOOLEAN,
   parent BIGINT ,
   root BIGINT ,
   translation_receipt BIGINT ,
   translation_competence INT ,
   translation_competence_selector BIGINT ,
   task_status BIGINT ,
   estimated_completion_time TIMESTAMP,
   required_completion_time TIMESTAMP,
   estimated_work_units FLOAT,
   work_units FLOAT,
   synchro BOOLEAN,
   sent TIMESTAMP,
   ordering_party_id BIGINT,
   task_type BIGINT,
   from_synchro BOOLEAN,
   priority BIGINT default 0,
   minimum_grade DOUBLE PRECISION,
   on_status_change_listener VARCHAR
 );
 CREATE TABLE translation_task_status_history (
  id INTEGER PRIMARY KEY AUTOINCREMENT,
  task BIGINT ,
  task_status BIGINT NOT NULL,
  changing_user BIGINT ,
  timestamp TIMESTAMP
 );
 CREATE TABLE money_transfer (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   translation_contract BIGINT ,
   amount_value DOUBLE PRECISION,
   amount_currency VARCHAR
 );
 CREATE TABLE credit_limmit (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   creditor BIGINT ,
   debtor BIGINT ,
   creadit_limit_value DOUBLE PRECISION,
   creadit_limit_currency VARCHAR
 );
 CREATE TABLE issue (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   submitter_id BIGINT ,
   consultant_id BIGINT ,
   task_id BIGINT ,
   summary BIGINT ,
   description BIGINT
 );
 CREATE TABLE translation_evaluation (
   id INTEGER PRIMARY KEY AUTOINCREMENT,
   evaluator BIGINT ,
   translation_task BIGINT
 );
CREATE INDEX unit_document_id_idx ON unit(document_id);
CREATE INDEX unit_creating_user_id_idx ON unit(creating_user_id);
CREATE INDEX unit_changing_user_id_idx ON unit(changing_user_id);
CREATE INDEX unit_document_id_position_idx ON unit(document_id, document_position);
CREATE INDEX variant_unit_id_idx ON variant(unit_id);
CREATE INDEX variant_creating_user_id_idx ON variant(creating_user_id);
CREATE INDEX variant_language_id_idx ON variant(language_id);
CREATE INDEX variant_quality_level_id_idx ON variant(quality_level_id);
CREATE INDEX variant_segment_idx ON variant(segment);
CREATE INDEX document_property_document_id_idx ON document_property(document_id);
CREATE INDEX document_note_document_id_idx ON document_note(document_id);
CREATE INDEX unit_property_unit_id_idx ON unit_property(unit_id);
CREATE INDEX unit_note_unit_id_idx ON unit_note(unit_id);
CREATE INDEX variant_property_unit_id_idx ON variant_property(variant_id);
CREATE INDEX variant_note_unit_id_idx ON variant_note(variant_id);
